server

package
v0.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 8, 2025 License: AGPL-3.0 Imports: 29 Imported by: 0

Documentation

Index

Constants

const (
	ReadCheckCancelledInterval       = 1 * time.Second
	RateLimitWindowSize              = 1 * time.Second
	RateLimitCountThresholdSus       = 3
	RateLimitCountThresholdMalicious = 10
)
const CertFile = "EKO_SERVER_CERT_FILE"

Variables

This section is empty.

Functions

func EvictSession

func EvictSession(sess *session.Session)

func NewServer

func NewServer(ctx context.Context, port uint16) server

NewServer creates a new server on the given port. Will generate a unique node ID automatically, will crash if there are no available IDs.

func TokensPerRequest

func TokensPerRequest(requestType packet.PacketType) float64

Types

This section is empty.

Directories

Path Synopsis

Jump to