Documentation
¶
Index ¶
Constants ¶
const ( ReadCheckCancelledInterval = 1 * time.Second RateLimitWindowSize = 1 * time.Second RateLimitCountThresholdSus = 3 RateLimitCountThresholdMalicious = 10 )
const CertFile = "EKO_SERVER_CERT_FILE"
Variables ¶
This section is empty.
Functions ¶
func EvictSession ¶
func NewServer ¶
NewServer creates a new server on the given port. Will generate a unique node ID automatically, will crash if there are no available IDs.
func TokensPerRequest ¶
func TokensPerRequest(requestType packet.PacketType) float64
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.